@@ -50,9 +50,9 @@ class CollectorPlugin(HopprPlugin):
         """
 
         repo_dir = plugin_utils.dir_name_from_repo_url(repo_url)
-        directory = f"{self.context.collect_root_dir}/{purl_type}/{repo_dir}/"
+        directory = os.path.join(self.context.collect_root_dir, purl_type, repo_dir)
         if subdir is not None:
-            directory += f"{subdir}/"
+            directory = os.path.join(directory, subdir)
         os.makedirs(directory, exist_ok=True)
         return directory
 
@@ -84,7 +84,7 @@ class CollectorPlugin(HopprPlugin):
     @hoppr_process
     def post_stage_process(self):
         for purl_type in self.supported_purl_types:
-            directory = f"{self.context.collect_root_dir}/{purl_type}"
+            directory = os.path.join(self.context.collect_root_dir, purl_type)
             if os.path.isdir(directory):
                 remove_empty(directory)
         return Result.success()
