@@ -1,6 +1,7 @@
 """
 Collector plugin for docker images
 """
+import os
 import re
 import urllib
 from typing import Any, Dict, Optional
@@ -38,19 +39,15 @@ class CollectDockerPlugin(CollectorPlugin):
         Copy a component to the local collection directory structure
         """
         purl = PackageURL.from_string(comp.purl)
-
-        source_url = re.sub(
-            "([^:])(//+)",
-            r"\1/",
-            f"{repo_url}/{purl.namespace}/{purl.name}:{purl.version}",
-        )
+        purl_id = purl.name + ":" + purl.version
+        source_url = os.path.join(repo_url, purl.namespace, purl_id)
         source_url = re.sub(r"^https?://", "", source_url)
         if not source_url.startswith("docker://"):
             source_url = "docker://" + source_url
 
-        file_name = urllib.parse.unquote(purl.name)
+        file_name = urllib.parse.unquote(purl.name) + "_" + purl.version
         target_dir = self.directory_for(purl.type, repo_url, subdir=purl.namespace)
-        destination = f"docker-archive:{target_dir}/{file_name}_{purl.version}"
+        destination = "docker-archive:" + os.path.join(target_dir, file_name)
 
         self.get_logger().info(
             f"Copying docker image from {source_url} to {destination}"
