@@ -1,6 +1,7 @@
 """
 Collector plugin for git repositories
 """
+import os
 import pathlib
 import re
 from typing import Any, Dict, Optional
@@ -41,9 +42,9 @@ class CollectGitPlugin(CollectorPlugin):
 
         self.get_logger().info(f"Copying git repository from {repo_url}")
 
-        source_url = f"{repo_url}/{purl.namespace}/{purl.name}"
+        source_url = os.path.join(repo_url, purl.namespace, purl.name)
         target_dir = self.directory_for(
-            purl.type, repo_url, subdir=f"{purl.namespace}/{purl.name}"
+            purl.type, repo_url, subdir=os.path.join(purl.namespace, purl.name)
         )
 
         result = self.git_clone(target_dir, source_url, creds)
@@ -91,7 +92,7 @@ class CollectGitPlugin(CollectorPlugin):
         if not name_git.endswith(".git"):
             name_git += ".git"
 
-        repo_dir = pathlib.Path(tmp_dir) / name_git
+        repo_dir = os.path.join(pathlib.Path(tmp_dir), name_git)
 
         # Make the clone usable as a remote
         result = self.run_command(
