@@ -1,6 +1,7 @@
 """
 Collector plugin for helm charts
 """
+import os
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
@@ -42,7 +43,7 @@ class CollectHelmPlugin(CollectorPlugin):
 
         self.get_logger().info(f"Copying helm chart from {repo_url}")
 
-        source_url = f"{repo_url}/{purl.name}"
+        source_url = os.path.join(repo_url, purl.name)
         target_dir = self.directory_for(
             purl.type, repo_url, subdir=f"{purl.name}_{purl.version}"
         )
