@@ -49,7 +49,7 @@ class CollectMavenPlugin(CollectorPlugin):
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.namespace}")
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+        self.get_logger().info(
             f"Copying maven artifact {purl.name}:{purl.version} from {repo_url} to {target_dir}"
         )
 
