@@ -1,6 +1,7 @@
 """
 Collector plugin for pypi images
 """
+import os
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
@@ -36,8 +37,8 @@ class CollectPypiPlugin(CollectorPlugin):
         Copy a component to the local collection directory structure
         """
         purl = PackageURL.from_string(comp.purl)
-
-        source_url = f"{repo_url}/simple"
+        if not repo_url.endswith("simple") or repo_url.endswith("simple/"):
+            source_url = os.path.join(repo_url, "simple")
         password_list = []
         if creds is not None:
             source_url = source_url.replace(
