@@ -32,9 +32,7 @@ class CollectRawPlugin(CollectorPlugin):
         """
         Copy a component to the local collection directory structure
         """
-        source_url = repo_url
-        if not source_url.endswith("/"):
-            source_url += "/"
+        source_url = os.path.join(repo_url)
 
         purl = PackageURL.from_string(comp.purl)
         subdir = None
