@@ -244,14 +244,14 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         )
         abs_path = os.path.abspath(file_name)
 
-        target = target_dir + urllib.parse.quote_plus(abs_path)
+        target = os.path.join(target_dir, urllib.parse.quote_plus(abs_path))
         shutil.copyfile(file_name, target)
 
     def _collect_url(self, url, target_dir) -> None:
         self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
             f"Collecting metadata from url {url}"
         )
-        target = target_dir + urllib.parse.quote_plus(url)
+        target = os.path.join(target_dir, urllib.parse.quote_plus(url))
         download_file(url, target, None)
 
     def _collect_manifest_metadata(self, manifest: Manifest, target_dir) -> None:
@@ -295,7 +295,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         os.makedirs(target_dir, exist_ok=True)
 
         with open(
-            target_dir + "_consolidated_bom.json", "w", encoding="utf-8"
+            os.path.join(target_dir, "_consolidated_bom.json"), "w", encoding="utf-8"
         ) as bom_data:
             bom_data.write(self.context.consolidated_sbom.json(by_alias=True, indent=2))
 
